Function torrust_tracker::bootstrap::app::setup
source · pub fn setup() -> (Arc<Configuration>, Arc<Tracker>)Expand description
It loads the configuration from the environment and builds the main domain tracker struct.
pub fn setup() -> (Arc<Configuration>, Arc<Tracker>)It loads the configuration from the environment and builds the main domain tracker struct.