Struct torrust_tracker::bootstrap::jobs::http_tracker::ServerJobStarted
source · pub struct ServerJobStarted();Expand description
This is the message that the “launcher” spawned task sends to the main application process to notify that the HTTP server was successfully started.
NOTICE: it does not mean the HTTP server is ready to receive requests. It only means the new server started. It might take some time to the server to be ready to accept request.