Setup for the application logging.

It redirects the log info to the standard output with the log level defined in the configuration.

  • Off
  • Error
  • Warn
  • Info
  • Debug
  • Trace

Refer to the configuration crate documentation to know how to change log settings.

Functions

  • It redirects the log info to the standard output with the log level defined in the configuration