Function torrust_tracker::bootstrap::logging::setup
source · pub fn setup(cfg: &Configuration)Expand description
It redirects the log info to the standard output with the log level defined in the configuration
pub fn setup(cfg: &Configuration)It redirects the log info to the standard output with the log level defined in the configuration