Struct torrust_tracker::servers::apis::InfoHashParam
source · pub struct InfoHashParam(pub String);Expand description
The info hash URL path parameter.
Some API endpoints require an info hash as a path parameter.
For example: http://localhost:1212/api/v1/torrent/{info_hash}.
The info hash represents teh value collected from the URL path parameter. It does not include validation as this is done by the API endpoint handler, in order to provide a more specific error message.
Tuple Fields
0: StringTrait Implementations
sourceimpl<'de> Deserialize<'de> for InfoHashParam
impl<'de> Deserialize<'de> for InfoHashParam
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more