pub fn check_fn(binding: &SocketAddr) -> ServiceHealthCheckJobExpand description
Checks the Health by connecting to the HTTP tracker endpoint.
Errors
This function will return an error if unable to connect. Or if the request returns an error.
pub fn check_fn(binding: &SocketAddr) -> ServiceHealthCheckJobChecks the Health by connecting to the HTTP tracker endpoint.
This function will return an error if unable to connect. Or if the request returns an error.