pub enum Error {
    MissingAuthKey {
        location: &'static Location<'static>,
    },
    InvalidKeyFormat {
        location: &'static Location<'static>,
    },
    CannotExtractKeyParam {
        location: &'static Location<'static>,
    },
}
Authentication error.

When the tracker is private, the authentication key is required in the URL path. These are the possible errors that can occur when extracting the key from the URL path.

Variants



MissingAuthKey

Fields

location: &'static Location<'static>


InvalidKeyFormat

Fields

location: &'static Location<'static>


CannotExtractKeyParam

Fields

location: &'static Location<'static>