Module error

Error response for the HTTP tracker.

Data structures and logic to build the error responses.

From the BEP 03. The BitTorrent Protocol Specification:

“Tracker responses are bencoded dictionaries. If a tracker response has a key failure reason, then that maps to a human readable string which explains why the query failed, and no other keys are required.”

NOTICE: error responses are bencoded and always have a 200 OK status code. The official BitTorrent specification does not specify the status code.

Structs

Error
Error response for the HTTP tracker.