Struct torrust_tracker::shared::bit_torrent::info_hash::InfoHash
source · pub struct InfoHash(pub [u8; 20]);Expand description
BitTorrent Info Hash v1
Tuple Fields
0: [u8; 20]Implementations
sourceimpl InfoHash
impl InfoHash
sourcepub fn from_bytes(bytes: &[u8]) -> Self
pub fn from_bytes(bytes: &[u8]) -> Self
Create a new InfoHash from a byte slice.
Panics
Will panic if byte slice does not contains the exact amount of bytes need for the InfoHash.
sourcepub fn to_hex_string(&self) -> String
pub fn to_hex_string(&self) -> String
Returns the InfoHash as a hex string.