pub trait TimeNow: Time {
    // Provided methods
    fn add(add_time: &Duration) -> Option<DurationSinceUnixEpoch> { ... }
    fn sub(sub_time: &Duration) -> Option<DurationSinceUnixEpoch> { ... }
}
Trait for types that can be manipulate the current time in order to get time in the future or in the past after or before a duration of time.

Provided Methods

Implementors