Module torrust_tracker::shared::crypto::ephemeral_instance_keys
source · Expand description
This module contains the ephemeral instance keys used by the application.
They are ephemeral because they are generated at runtime when the application starts and are not persisted anywhere.
Structs
- The random static seed.