Struct torrust_tracker::tracker::auth::ExpiringKey
source · pub struct ExpiringKey {
pub key: Key,
pub valid_until: DurationSinceUnixEpoch,
}Expand description
An authentication key which has an expiration time. After that time is will automatically become invalid.
Fields
key: KeyRandom 32-char string. For example: YZSl4lMZupRuOpSRC3krIKR5BPB14nrJ
valid_until: DurationSinceUnixEpochTimestamp, the key will be no longer valid after this timestamp
Implementations
sourceimpl ExpiringKey
impl ExpiringKey
pub fn key(&self) -> Key
sourcepub fn expiry_time(&self) -> DateTime<Utc>
pub fn expiry_time(&self) -> DateTime<Utc>
It returns the expiry time. For example, for the starting time for Unix Epoch
(timestamp 0) it will return a DateTime whose string representation is
1970-01-01 00:00:00 UTC.
Panics
Will panic when the key timestamp overflows the internal i64 type. (this will naturally happen in 292.5 billion years)