Struct torrust_tracker::tracker::auth::ParseKeyError
source · pub struct ParseKeyError;Expand description
Error returned when a key cannot be parsed from a string.
use torrust_tracker::tracker::auth::Key;
use std::str::FromStr;
let key_string = "YZSl4lMZupRuOpSRC3krIKR5BPB14nrJ";
let key = Key::from_str(key_string);
assert!(key.is_ok());
assert_eq!(key.unwrap().to_string(), key_string);If the string does not contains a valid key, the parser function will return this error.