Struct torrust_tracker::tracker::peer::Id
source · pub struct Id(pub [u8; 20]);Expand description
Peer ID. A 20-byte array.
A string of length 20 which this downloader uses as its id. Each downloader generates its own id at random at the start of a new download.
A sample peer ID:
use torrust_tracker::tracker::peer;
let peer_id = peer::Id(*b"-qB00000000000000000");Tuple Fields
0: [u8; 20]Implementations
sourceimpl Id
impl Id
sourcepub fn to_hex_string(&self) -> Option<String>
pub fn to_hex_string(&self) -> Option<String>
Converts to hex string.
For the Id -qB00000000000000000 it returns 2d71423030303030303030303030303030303030
For example:
Bytes = Hex
-qB00000000000000000 = 2d71423030303030303030303030303030303030
-qB00000000000000000 = 2d 71 42 30 30 30 30 30 30 30 30 30 30 30 30 30 30 30 30 30
-------------
|Char | Hex |
-------------
| - | 2D |
| q | 71 |
| B | 42 |
| 0 | 30 |
-------------
Return None is some of the bytes are invalid UTF8 values.
Panics
It will panic if the binascii::bin2hex from a too-small output buffer.
pub fn get_client_name(&self) -> Option<&'static str>