pub struct Peer {
    pub peer_id: Id,
    pub peer_addr: SocketAddr,
    pub updated: DurationSinceUnixEpoch,
    pub uploaded: NumberOfBytes,
    pub downloaded: NumberOfBytes,
    pub left: NumberOfBytes,
    pub event: AnnounceEvent,
}
Peer struct used by the core Tracker.

A sample peer:

use torrust_tracker::tracker::peer;
use std::net::SocketAddr;
use std::net::IpAddr;
use std::net::Ipv4Addr;
use torrust_tracker::shared::clock::DurationSinceUnixEpoch;
use aquatic_udp_protocol::{AnnounceEvent, NumberOfBytes};

peer::Peer {
    peer_id: peer::Id(*b"-qB00000000000000000"),
    peer_addr: SocketAddr::new(IpAddr::V4(Ipv4Addr::new(126, 0, 0, 1)), 8080),
    updated: DurationSinceUnixEpoch::new(1_669_397_478_934, 0),
    uploaded: NumberOfBytes(0),
    downloaded: NumberOfBytes(0),
    left: NumberOfBytes(0),
    event: AnnounceEvent::Started,
};

Fields

peer_id: Id

ID used by the downloader peer

peer_addr: SocketAddr

The IP and port this peer is listening on

updated: DurationSinceUnixEpoch

The last time the the tracker receive an announce request from this peer (timestamp)

uploaded: NumberOfBytes

The total amount of bytes uploaded by this peer so far

downloaded: NumberOfBytes

The total amount of bytes downloaded by this peer so far

left: NumberOfBytes

The number of bytes this peer still has to download

event: AnnounceEvent

This is an optional key which maps to started, completed, or stopped (or empty, which is the same as not being present).

Implementations

source

impl Peer

source

pub fn is_seeder(&self) -> bool

source

pub fn ip(&mut self) -> IpAddr

source

pub fn change_ip(&mut self, new_ip: &IpAddr)

source

pub fn ip_version(&self) -> IPVersion

The IP version used by the peer: IPV4 or IPV6