Module torrust_tracker::tracker::services::statistics::setup
source · Expand description
Setup for the tracker statistics.
The factory function builds the structs needed for handling the tracker metrics.
Functions
- It builds the structs needed for handling the tracker metrics.