Struct torrust_tracker::tracker::services::statistics::TrackerMetrics
source · pub struct TrackerMetrics {
pub torrents_metrics: TorrentsMetrics,
pub protocol_metrics: Metrics,
}Expand description
All the metrics collected by the tracker.
Fields
torrents_metrics: TorrentsMetricsDomain level metrics.
General metrics for all torrents (number of seeders, leechers, etcetera)
protocol_metrics: MetricsApplication level metrics. Usage statistics/metrics.
Metrics about how the tracker is been used (number of udp announce requests, number of http scrape requests, etcetera)