pub struct BasicInfo {
pub info_hash: InfoHash,
pub seeders: u64,
pub completed: u64,
pub leechers: u64,
}Expand description
It contains only part of the information the tracker has about a torrent
It contains the same data as Info but without the list of peers in the swarm.
Fields
info_hash: InfoHashThe infohash of the torrent this data is related to
seeders: u64The total number of seeders for this torrent. Peer that actively serving a full copy of the torrent data
completed: u64The total number of peers that have ever complete downloading this torrent
leechers: u64The total number of leechers for this torrent. Peers that actively downloading this torrent