pub struct Tracker {
    pub config: Arc<Configuration>,
    pub database: Box<dyn Database>,
    /* private fields */
}

Fields

config: Arc<Configuration>database: Box<dyn Database>

Implementations

source

impl Tracker

source

pub fn new( config: Arc<Configuration>, stats_event_sender: Option<Box<dyn EventSender>>, stats_repository: Repo ) -> Result<Tracker, Error>

Errors

Will return a databases::error::Error if unable to connect to database.

source

pub fn is_public(&self) -> bool

source

pub fn is_private(&self) -> bool

source

pub fn is_whitelisted(&self) -> bool

source

pub fn requires_authentication(&self) -> bool

source

pub async fn announce( &self, info_hash: &InfoHash, peer: &mut Peer, remote_client_ip: &IpAddr ) -> AnnounceData

It handles an announce request.

BEP 03: The BitTorrent Protocol Specification.

source

pub async fn scrape(&self, info_hashes: &Vec<InfoHash>) -> ScrapeData

It handles a scrape request.

BEP 48: Tracker Protocol Extension: Scrape.

source

pub async fn generate_auth_key( &self, lifetime: Duration ) -> Result<ExpiringKey, Error>

Errors

Will return a database::Error if unable to add the auth_key to the database.

source

pub async fn remove_auth_key(&self, key: &Key) -> Result<(), Error>

Errors

Will return a database::Error if unable to remove the key to the database.

Panics

Will panic if key cannot be converted into a valid Key.

source

pub async fn verify_auth_key(&self, key: &Key) -> Result<(), Error>

Errors

Will return a key::Error if unable to get any auth_key.

source

pub async fn load_keys_from_database(&self) -> Result<(), Error>

Errors

Will return a database::Error if unable to load_keys from the database.

source

pub async fn add_torrent_to_whitelist( &self, info_hash: &InfoHash ) -> Result<(), Error>

Adding torrents is not relevant to public trackers.

Errors

Will return a database::Error if unable to add the info_hash into the whitelist database.

source

pub async fn add_torrent_to_memory_whitelist( &self, info_hash: &InfoHash ) -> bool

source

pub async fn remove_torrent_from_whitelist( &self, info_hash: &InfoHash ) -> Result<(), Error>

Removing torrents is not relevant to public trackers.

Errors

Will return a database::Error if unable to remove the info_hash from the whitelist database.

source

pub async fn remove_torrent_from_database_whitelist( &self, info_hash: &InfoHash ) -> Result<(), Error>

Errors

Will return a database::Error if unable to remove the info_hash from the whitelist database.

source

pub async fn remove_torrent_from_memory_whitelist( &self, info_hash: &InfoHash ) -> bool

source

pub async fn is_info_hash_whitelisted(&self, info_hash: &InfoHash) -> bool

source

pub async fn load_whitelist_from_database(&self) -> Result<(), Error>

Errors

Will return a database::Error if unable to load the list whitelisted info_hashs from the database.

source

pub async fn authenticate_request( &self, info_hash: &InfoHash, key: &Option<Key> ) -> Result<(), Error>

Errors

Will return a torrent::Error::PeerKeyNotValid if the key is not valid.

Will return a torrent::Error::PeerNotAuthenticated if the key is None.

Will return a torrent::Error::TorrentNotWhitelisted if the the Tracker is in listed mode and the info_hash is not whitelisted.

source

pub async fn authenticate(&self, key: &Key) -> Result<(), Error>

Errors

Will return an error if the the authentication key cannot be verified.

source

pub async fn authorize(&self, info_hash: &InfoHash) -> Result<(), Error>

The only authorization process is the whitelist.

Errors

Will return an error if the tracker is running in listed mode and the infohash is not whitelisted.

source

pub async fn load_torrents_from_database(&self) -> Result<(), Error>

Loading the torrents from database into memory

Errors

Will return a database::Error if unable to load the list of persistent_torrents from the database.

source

pub async fn get_all_torrent_peers(&self, info_hash: &InfoHash) -> Vec<Peer>

Get all torrent peers for a given torrent

source

pub async fn update_torrent_with_peer_and_get_stats( &self, info_hash: &InfoHash, peer: &Peer ) -> SwarmStats

source

pub async fn get_torrents( &self ) -> RwLockReadGuard<'_, BTreeMap<InfoHash, Entry>>

source

pub async fn get_torrents_metrics(&self) -> TorrentsMetrics

source

pub async fn get_stats(&self) -> RwLockReadGuard<'_, Metrics>

source

pub async fn send_stats_event( &self, event: Event ) -> Option<Result<(), SendError<Event>>>

source

pub async fn cleanup_torrents(&self)