pub struct Entry {
    pub peers: BTreeMap<Id, Peer>,
    pub completed: u32,
}
A data structure containing all the information about a torrent in the tracker.

This is the tracker entry for a given torrent and contains the swarm data, that’s the list of all the peers trying to download the same torrent. The tracker keeps one entry like this for every torrent.

Fields

peers: BTreeMap<Id, Peer>

The swarm: a network of peers that are all trying to download the torrent associated to this entry

completed: u32

The number of peers that have ever completed downloading the torrent associated to this entry

Implementations

source

impl Entry

source

pub fn new() -> Entry

source

pub fn update_peer(&mut self, peer: &Peer) -> bool

It updates a peer and returns true if the number of complete downloads have increased.

The number of peers that have complete downloading is synchronously updated when peers are updated. That’s the total torrent downloads counter.

source

pub fn get_all_peers(&self) -> Vec<&Peer>

Get all swarm peers, limiting the result to the maximum number of scrape torrents.

source

pub fn get_peers_for_peer(&self, client: &Peer) -> Vec<&Peer>

It returns the list of peers for a given peer client, limiting the result to the maximum number of scrape torrents.

It filters out the input peer, typically because we want to return this list of peers to that client peer.

source

pub fn get_stats(&self) -> (u32, u32, u32)

It returns the swarm metadata (statistics) as a tuple:

(seeders, completed, leechers)

source

pub fn get_swarm_metadata(&self) -> SwarmMetadata

It returns the swarm metadata (statistics) as an struct

source

pub fn remove_inactive_peers(&mut self, max_peer_timeout: u32)

It removes peer from the swarm that have not been updated for more than max_peer_timeout seconds