Module torrust_tracker::bootstrap::app
source · Expand description
Setup for the main tracker application.
The setup only builds the application and its dependencies but it does not start the application.
In fact, there is no such thing as the main application process. When the application starts, the only thing it does is
starting a bunch of independent jobs. If you are looking for how things are started you should read app::start
function documentation.
Setup steps:
- Load the global application configuration.
- Initialize static variables.
- Initialize logging.
- Initialize the domain tracker.
Functions
- It initializes the log level, format and channel.
- It initializes the application static values.
- It builds the domain tracker
- It initializes the application with the given configuration.
- It loads the configuration from the environment and builds the main domain
trackerstruct.