Module app

Setup for the main tracker application.

The setup only builds the application and its dependencies but it does not start the application. In fact, there is no such thing as the main application process. When the application starts, the only thing it does is starting a bunch of independent jobs. If you are looking for how things are started you should read app::start function documentation.

Setup steps:

  1. Load the global application configuration.
  2. Initialize static variables.
  3. Initialize logging.
  4. Initialize the domain tracker.

Functions

initialize_logging
It initializes the log threshold, format and channel.
initialize_static
It initializes the application static values.
initialize_tracker
It builds the domain tracker
initialize_with_configuration
It initializes the application with the given configuration.
setup
It loads the configuration from the environment and builds the main domain Tracker struct.