Core tracker domain services.
There are two services:
get_torrent_info: it returns all the data about one torrent.get_torrents: it returns data about some torrent in bulk excluding the peer list.
Structs
- Basic
Info - It contains only part of the information the tracker has about a torrent
- Info
- It contains all the information the tracker has about a torrent
Functions
- get_
torrent_ info - It returns all the information the tracker has about one torrent in a Info struct.
- get_
torrents - It returns all the information the tracker has about multiple torrents in a
BasicInfostruct, excluding the peer list. - get_
torrents_ page - It returns all the information the tracker has about multiple torrents in a
BasicInfostruct, excluding the peer list.