Struct torrust_tracker::tracker::peer::Peer
source · pub struct Peer {
pub peer_id: Id,
pub peer_addr: SocketAddr,
pub updated: DurationSinceUnixEpoch,
pub uploaded: NumberOfBytes,
pub downloaded: NumberOfBytes,
pub left: NumberOfBytes,
pub event: AnnounceEvent,
}Expand description
Peer struct used by the core Tracker.
A sample peer:
use torrust_tracker::tracker::peer;
use std::net::SocketAddr;
use std::net::IpAddr;
use std::net::Ipv4Addr;
use torrust_tracker::shared::clock::DurationSinceUnixEpoch;
use aquatic_udp_protocol::{AnnounceEvent, NumberOfBytes};
peer::Peer {
peer_id: peer::Id(*b"-qB00000000000000000"),
peer_addr: SocketAddr::new(IpAddr::V4(Ipv4Addr::new(126, 0, 0, 1)), 8080),
updated: DurationSinceUnixEpoch::new(1_669_397_478_934, 0),
uploaded: NumberOfBytes(0),
downloaded: NumberOfBytes(0),
left: NumberOfBytes(0),
event: AnnounceEvent::Started,
};Fields
peer_id: IdID used by the downloader peer
peer_addr: SocketAddrThe IP and port this peer is listening on
updated: DurationSinceUnixEpochThe last time the the tracker receive an announce request from this peer (timestamp)
uploaded: NumberOfBytesThe total amount of bytes uploaded by this peer so far
downloaded: NumberOfBytesThe total amount of bytes downloaded by this peer so far
left: NumberOfBytesThe number of bytes this peer still has to download
event: AnnounceEventThis is an optional key which maps to started, completed, or stopped (or empty, which is the same as not being present).
Implementations