Struct torrust_tracker::tracker::Tracker
source · pub struct Tracker {
pub config: Arc<Configuration>,
pub database: Box<dyn Database>,
/* private fields */
}Fields
config: Arc<Configuration>database: Box<dyn Database>Implementations
sourceimpl Tracker
impl Tracker
sourcepub fn new(
config: Arc<Configuration>,
stats_event_sender: Option<Box<dyn EventSender>>,
stats_repository: Repo
) -> Result<Tracker, Error>
pub fn new( config: Arc<Configuration>, stats_event_sender: Option<Box<dyn EventSender>>, stats_repository: Repo ) -> Result<Tracker, Error>
Errors
Will return a databases::error::Error if unable to connect to database.
pub fn is_public(&self) -> bool
pub fn is_private(&self) -> bool
pub fn is_whitelisted(&self) -> bool
pub fn requires_authentication(&self) -> bool
sourcepub async fn announce(
&self,
info_hash: &InfoHash,
peer: &mut Peer,
remote_client_ip: &IpAddr
) -> AnnounceData
pub async fn announce( &self, info_hash: &InfoHash, peer: &mut Peer, remote_client_ip: &IpAddr ) -> AnnounceData
It handles an announce request.
sourcepub async fn scrape(&self, info_hashes: &Vec<InfoHash>) -> ScrapeData
pub async fn scrape(&self, info_hashes: &Vec<InfoHash>) -> ScrapeData
It handles a scrape request.
BEP 48: Tracker Protocol Extension: Scrape.
sourcepub async fn generate_auth_key(
&self,
lifetime: Duration
) -> Result<ExpiringKey, Error>
pub async fn generate_auth_key( &self, lifetime: Duration ) -> Result<ExpiringKey, Error>
Errors
Will return a database::Error if unable to add the auth_key to the database.
sourcepub async fn verify_auth_key(&self, key: &Key) -> Result<(), Error>
pub async fn verify_auth_key(&self, key: &Key) -> Result<(), Error>
Errors
Will return a key::Error if unable to get any auth_key.
sourcepub async fn load_keys_from_database(&self) -> Result<(), Error>
pub async fn load_keys_from_database(&self) -> Result<(), Error>
Errors
Will return a database::Error if unable to load_keys from the database.
sourcepub async fn add_torrent_to_whitelist(
&self,
info_hash: &InfoHash
) -> Result<(), Error>
pub async fn add_torrent_to_whitelist( &self, info_hash: &InfoHash ) -> Result<(), Error>
Adding torrents is not relevant to public trackers.
Errors
Will return a database::Error if unable to add the info_hash into the whitelist database.
pub async fn add_torrent_to_memory_whitelist( &self, info_hash: &InfoHash ) -> bool
sourcepub async fn remove_torrent_from_whitelist(
&self,
info_hash: &InfoHash
) -> Result<(), Error>
pub async fn remove_torrent_from_whitelist( &self, info_hash: &InfoHash ) -> Result<(), Error>
Removing torrents is not relevant to public trackers.
Errors
Will return a database::Error if unable to remove the info_hash from the whitelist database.
sourcepub async fn remove_torrent_from_database_whitelist(
&self,
info_hash: &InfoHash
) -> Result<(), Error>
pub async fn remove_torrent_from_database_whitelist( &self, info_hash: &InfoHash ) -> Result<(), Error>
Errors
Will return a database::Error if unable to remove the info_hash from the whitelist database.
pub async fn remove_torrent_from_memory_whitelist( &self, info_hash: &InfoHash ) -> bool
pub async fn is_info_hash_whitelisted(&self, info_hash: &InfoHash) -> bool
sourcepub async fn load_whitelist_from_database(&self) -> Result<(), Error>
pub async fn load_whitelist_from_database(&self) -> Result<(), Error>
Errors
Will return a database::Error if unable to load the list whitelisted info_hashs from the database.
sourcepub async fn authenticate_request(
&self,
info_hash: &InfoHash,
key: &Option<Key>
) -> Result<(), Error>
pub async fn authenticate_request( &self, info_hash: &InfoHash, key: &Option<Key> ) -> Result<(), Error>
Errors
Will return a torrent::Error::PeerKeyNotValid if the key is not valid.
Will return a torrent::Error::PeerNotAuthenticated if the key is None.
Will return a torrent::Error::TorrentNotWhitelisted if the the Tracker is in listed mode and the info_hash is not whitelisted.
sourcepub async fn authenticate(&self, key: &Key) -> Result<(), Error>
pub async fn authenticate(&self, key: &Key) -> Result<(), Error>
Errors
Will return an error if the the authentication key cannot be verified.
The only authorization process is the whitelist.
Errors
Will return an error if the tracker is running in listed mode
and the infohash is not whitelisted.
sourcepub async fn load_torrents_from_database(&self) -> Result<(), Error>
pub async fn load_torrents_from_database(&self) -> Result<(), Error>
Loading the torrents from database into memory
Errors
Will return a database::Error if unable to load the list of persistent_torrents from the database.
sourcepub async fn get_all_torrent_peers(&self, info_hash: &InfoHash) -> Vec<Peer> ⓘ
pub async fn get_all_torrent_peers(&self, info_hash: &InfoHash) -> Vec<Peer> ⓘ
Get all torrent peers for a given torrent
pub async fn update_torrent_with_peer_and_get_stats( &self, info_hash: &InfoHash, peer: &Peer ) -> SwarmStats
pub async fn get_torrents( &self ) -> RwLockReadGuard<'_, BTreeMap<InfoHash, Entry>>
pub async fn get_torrents_metrics(&self) -> TorrentsMetrics
pub async fn get_stats(&self) -> RwLockReadGuard<'_, Metrics>
pub async fn send_stats_event( &self, event: Event ) -> Option<Result<(), SendError<Event>>>
pub async fn cleanup_torrents(&self)