pub struct Tracker {
    pub config: Arc<Configuration>,
    pub database: Box<dyn Database>,
    /* private fields */
}
The domain layer tracker service.

Its main responsibility is to handle the announce and scrape requests. But it’s also a container for the Tracker configuration, persistence, authentication and other services.

NOTICE: the Tracker is not responsible for handling the network layer. Typically, the Tracker is used by a higher application service that handles the network layer.

Fields

config: Arc<Configuration>

Tracker configuration. See torrust-tracker-configuration

database: Box<dyn Database>

A database driver implementation: Sqlite3 or MySQL

Implementations

source

impl Tracker

source

pub fn new( config: Arc<Configuration>, stats_event_sender: Option<Box<dyn EventSender>>, stats_repository: Repo ) -> Result<Tracker, Error>

Tracker constructor.

Errors

Will return a databases::error::Error if unable to connect to database. The Tracker is responsible for the persistence.

source

pub fn is_public(&self) -> bool

Returns true is the tracker is in public mode.

source

pub fn is_private(&self) -> bool

Returns true is the tracker is in private mode.

source

pub fn is_whitelisted(&self) -> bool

Returns true is the tracker is in whitelisted mode.

source

pub fn requires_authentication(&self) -> bool

Returns true if the tracker requires authentication.

source

pub async fn announce( &self, info_hash: &InfoHash, peer: &mut Peer, remote_client_ip: &IpAddr ) -> AnnounceData

It handles an announce request.

Context: Tracker

BEP 03: The BitTorrent Protocol Specification.

source

pub async fn scrape(&self, info_hashes: &Vec<InfoHash>) -> ScrapeData

It handles a scrape request.

Context: Tracker

BEP 48: Tracker Protocol Extension: Scrape.

source

pub async fn load_torrents_from_database(&self) -> Result<(), Error>

It loads the torrents from database into memory. It only loads the torrent entry list with the number of seeders for each torrent. Peers data is not persisted.

Context: Tracker
Errors

Will return a database::Error if unable to load the list of persistent_torrents from the database.

source

pub async fn get_all_torrent_peers(&self, info_hash: &InfoHash) -> Vec<Peer>

Context: Tracker

Get all torrent peers for a given torrent

source

pub async fn update_torrent_with_peer_and_get_stats( &self, info_hash: &InfoHash, peer: &Peer ) -> SwarmStats

It updates the torrent entry in memory, it also stores in the database the torrent info data which is persistent, and finally return the data needed for a announce request response.

Context: Tracker
source

pub async fn get_torrents( &self ) -> RwLockReadGuard<'_, BTreeMap<InfoHash, Entry>>

source

pub async fn get_torrents_metrics(&self) -> TorrentsMetrics

It calculates and returns the general Tracker TorrentsMetrics

Context: Tracker
source

pub async fn cleanup_torrents(&self)

Remove inactive peers and (optionally) peerless torrents

Context: Tracker
source

pub async fn authenticate(&self, key: &Key) -> Result<(), Error>

It authenticates the peer key against the Tracker authentication key list.

Errors

Will return an error if the the authentication key cannot be verified.

Context: Authentication
source

pub async fn generate_auth_key( &self, lifetime: Duration ) -> Result<ExpiringKey, Error>

It generates a new expiring authentication key. lifetime param is the duration in seconds for the new key. The key will be no longer valid after lifetime seconds. Authentication keys are used by HTTP trackers.

Context: Authentication
Errors

Will return a database::Error if unable to add the auth_key to the database.

source

pub async fn remove_auth_key(&self, key: &Key) -> Result<(), Error>

It removes an authentication key.

Context: Authentication
Errors

Will return a database::Error if unable to remove the key to the database.

Panics

Will panic if key cannot be converted into a valid Key.

source

pub async fn verify_auth_key(&self, key: &Key) -> Result<(), Error>

It verifies an authentication key.

Context: Authentication
Errors

Will return a key::Error if unable to get any auth_key.

source

pub async fn load_keys_from_database(&self) -> Result<(), Error>

The Tracker stores the authentication keys in memory and in the database. In case you need to restart the Tracker you can load the keys from the database into memory with this function. Keys are automatically stored in the database when they are generated.

Context: Authentication
Errors

Will return a database::Error if unable to load_keys from the database.

source

pub async fn authenticate_request( &self, info_hash: &InfoHash, key: &Option<Key> ) -> Result<(), Error>

👎Deprecated since 3.0.0: please use authenticate and authorize instead

It authenticates and authorizes a UDP tracker request.

Context: Authentication and Authorization
Errors

Will return a torrent::Error::PeerKeyNotValid if the key is not valid.

Will return a torrent::Error::PeerNotAuthenticated if the key is None.

Will return a torrent::Error::TorrentNotWhitelisted if the the Tracker is in listed mode and the info_hash is not whitelisted.

source

pub async fn authorize(&self, info_hash: &InfoHash) -> Result<(), Error>

Right now, there is only authorization when the Tracker runs in listed or private_listed modes.

Context: Authorization
Errors

Will return an error if the tracker is running in listed mode and the infohash is not whitelisted.

source

pub async fn add_torrent_to_whitelist( &self, info_hash: &InfoHash ) -> Result<(), Error>

It adds a torrent to the whitelist. Adding torrents is not relevant to public trackers.

Context: Whitelist
Errors

Will return a database::Error if unable to add the info_hash into the whitelist database.

source

pub async fn add_torrent_to_memory_whitelist( &self, info_hash: &InfoHash ) -> bool

source

pub async fn remove_torrent_from_whitelist( &self, info_hash: &InfoHash ) -> Result<(), Error>

It removes a torrent from the whitelist. Removing torrents is not relevant to public trackers.

Context: Whitelist
Errors

Will return a database::Error if unable to remove the info_hash from the whitelist database.

source

pub async fn remove_torrent_from_database_whitelist( &self, info_hash: &InfoHash ) -> Result<(), Error>

It removes a torrent from the whitelist in the database.

Context: Whitelist
Errors

Will return a database::Error if unable to remove the info_hash from the whitelist database.

source

pub async fn remove_torrent_from_memory_whitelist( &self, info_hash: &InfoHash ) -> bool

It removes a torrent from the whitelist in memory.

Context: Whitelist
source

pub async fn is_info_hash_whitelisted(&self, info_hash: &InfoHash) -> bool

It checks if a torrent is whitelisted.

Context: Whitelist
source

pub async fn load_whitelist_from_database(&self) -> Result<(), Error>

It loads the whitelist from the database.

Context: Whitelist
Errors

Will return a database::Error if unable to load the list whitelisted info_hashs from the database.

source

pub async fn get_stats(&self) -> RwLockReadGuard<'_, Metrics>

source

pub async fn send_stats_event( &self, event: Event ) -> Option<Result<(), SendError<Event>>>

It allows to send a statistic events which eventually will be used to update statistics::Metrics.

Context: Statistics